# oagdedupe  

```
This project is under active development.
```

oagdedupe is a Python library for scalable entity resolution, using active 
learning to learn blocking configurations, generate comparison pairs, 
then clasify matches. 

# installation<a name="#installation"></a>

```
# PyPI
pip install oagdedupe
```

# documentation<a name="#documentation"></a>

You can find the documentation of oagdedupe at https://deduper.readthedocs.io/en/latest/, 
where you can find: 

- [Installation and Getting Started](https://deduper.readthedocs.io/en/latest/usage/installation.html)
- [Examples](https://deduper.readthedocs.io/en/latest/examples/example_dedupe.html)
- the [API reference](https://deduper.readthedocs.io/en/latest/dedupe/api.html)
- [User Guide / Methodology](https://deduper.readthedocs.io/en/latest/userguide/intro.html)

